@@ -21,4 +21,6 @@ pub mod huffman;
 /// Bloom filter
 pub mod bloom_filter;
 /// Sparse table
-pub mod sparse_table;
\ No newline at end of file
+pub mod sparse_table;
+/// Binary Tree
+pub mod binary_tree;
\ No newline at end of file
